# PYTOHub

PYTOHub is a program that can directly connect to your lego spike prime or mindstorms hub

![alt text](banner.png)

# How to download

How to download PYToHub

**Run this in your terminal (Command prompt)**
```
pip install pytohub
```

Press `enter` when you see your hub's serial port, Make sure that you setted up your lego hub for pytohub to connect.

# How to run pytohub

**You can directly run it in the terminal**
```
python -m pytohub
```

# How to setup your lego hub

You need to setup your lego hub

**You can directly run it in the terminal**
```
python -m pytohub --download
```

